<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  カテゴリ名称の取得
 *
 *  @access public
 *  @param  integer $category_id        カテゴリID
 */
function db_get_category_name($category_id)
{
    $sql = 'SELECT category_name' .
            ' FROM pb_categories' .
            ' WHERE category_id = ?';
    $params = array(
        intval($category_id)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  カテゴリ一覧情報の取得
 *
 *  @access public
 */
function db_get_categories4admin()
{
    $sql = 'SELECT category_id, category_name, outline, sort_order, r_datetime' .
            ' FROM pb_categories' .
            ' ORDER BY sort_order';
    return pocket_db_getAll($sql);
}

/**
 *  カテゴリ一覧情報の取得
 *
 *  @access public
 */
function db_get_categories4category_list()
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT category_id, category_name, outline, sort_order, r_datetime' .
            ' FROM pb_categories' .
            ' ORDER BY sort_order';
    $list = pocket_db_getAll($sql);
    foreach ($list as $key => $item)
    {
        $list[$key]['post_count'] = db_get_category_posts_count($item['category_id']);
    }
    return $list;
}

/**
 *  カテゴリの記事件数の取得
 *
 *  @access public
 *  @param  integer $category_id        カテゴリID
 */
function db_get_category_posts_count($category_id)
{
    $sql = 'SELECT count(cp.post_id) AS post_count' .
            ' FROM pb_category_posts AS cp' .
            ' LEFT JOIN pb_posts AS p' .
                ' ON cp.post_id = p.post_id' .
            ' WHERE p.is_open = ?' .
            ' AND cp.category_id = ?';
    $params = array(
        intval(true),
        intval($category_id)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  カテゴリ情報の登録
 *
 *  @access public
 *  @param  string  $category_name      カテゴリ名
 *  @param  string  $outline            概要
 *  @param  integer $sort_order         表示順
 */
function db_insert_category($category_name, $outline, $sort_order)
{
    $data = array(
        'category_name' => $category_name,
        'outline' => $outline,
        'sort_order' => intval($sort_order),
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pb_categories', $data, 'pb_categories_category_id_seq');
}

/**
 *  カテゴリ情報の更新
 *
 *  @access public
 *  @param  integer $category_id        ID
 *  @param  string  $category_name      カテゴリ名
 *  @param  string  $outline            概要
 *  @param  integer $sort_order         表示順
 */
function db_update_category($category_id, $category_name, $outline, $sort_order)
{
    $data = array(
        'category_name' => $category_name,
        'outline' => $outline,
        'sort_order' => intval($sort_order),
        'r_datetime' => pocket_db_getNow()
    );
    $where = array(
        'category_id' => intval($category_id)
    );
    return pocket_db_update('pb_categories', $data, $where);
}

/**
 *  カテゴリ情報の削除
 *
 *  @access public
 *  @param  integer $category_id            ID
 */
function db_delete_category($category_id)
{
    if (!db_update_posts_category4default($category_id)) {return false;}
    return pocket_db_delete('pb_categories', 'category_id', intval($category_id));
}

?>
